@@ -12,13 +12,14 @@ use strict;
 use warnings;
 
 use HiPi qw( :energenie :openthings );
-use Time::HiRes qw( usleep );
 use HiPi::Energenie::ENER314_RT;
+use Time::HiRes qw( usleep );
 use HiPi::RF::OpenThings::Message;
+use HiPi::RF::OpenThings;
 
-our $VERSION ='0.61';
+our $VERSION ='0.66';
 
-my $handler = HiPi::Energenie::ENER314_RT->new;
+my $handler = HiPi::Energenie::ENER314_RT->new( led_on => 0 );
 
 # keep a hash of switches we have 'registered'
 my $switch_states = {};
@@ -35,23 +36,26 @@ while (1) {
     my $switchstate = 0;
     my $sensorkey = 'NOT KNOWN';
     if ( $msg ) {
-        my $received = scalar(localtime($msg->epoch));
-        print qq(\nMessage recieved $received\n);
+        $msg->decode_buffer unless $msg->is_decoded;
         
-        $sensorkey = $msg->sensor_key;
-        
-        printf(qq(\tManufacturer ID: 0x%04x, Product ID: 0x%04x, Sensor ID: 0x%06x, Encrypt PIP: 0x%04x\n), $msg->manufacturer_id, $msg->product_id, $msg->sensor_id, $msg->encrypt_pip);
-        printf(qq(\tSensor Key: %s\n), $msg->sensor_key);
-        if( $msg->manufacturer_id == ENERGENIE_MANUFACTURER_ID ) {
-            my $productname = $handler->map_product_to_name( $msg->product_id );
-            print qq(\tEnergenie : $productname\n);
-        }
-        my @joinrecords = ();
-        if ( $msg->ok ) {
+        if( $msg->ok ) {
+            my $received = scalar(localtime($msg->epoch));
+            print qq(\nMessage recieved $received\n);
+            
+            $sensorkey = $msg->sensor_key;
+            
+            printf(qq(\tManufacturer ID: 0x%04x, Product ID: 0x%04x, Sensor ID: 0x%06x, Encrypt PIP: 0x%04x\n), $msg->manufacturer_id, $msg->product_id, $msg->sensor_id, $msg->encrypt_pip);
+            printf(qq(\tSensor Key: %s\n), $msg->sensor_key);
+            if( $msg->manufacturer_id == ENERGENIE_MANUFACTURER_ID ) {
+                my $productname = HiPi::RF::OpenThings->product_name($msg->manufacturer_id, $msg->product_id );
+                print qq(\tEnergenie : $productname\n);
+            }
+            
+            my @joinrecords = ();
             
             for my $record ( @{ $msg->records } ) {
-                printf(qq(\t%s = %s ( command bit %s)\n), $record->name, $record->value . $record->units, $record->wr || '0');
-                if ( $record->id == OPENTHINGS_PARAM_JOIN && $record->wr ) {
+                printf(qq(\t%s = %s ( command bit %s)\n), $record->name, $record->value . $record->units, $record->command || '0');
+                if ( $record->id == OPENTHINGS_PARAM_JOIN && $record->command ) {
                     push @joinrecords, $record;
                 } elsif( $record->id == OPENTHINGS_PARAM_SWITCH_STATE ) {
                     $messagefromswitch = 1;
@@ -81,12 +85,12 @@ while (1) {
                     mid => $msg->manufacturer_id,
                     pid => $msg->product_id,
                     sid => $msg->sensor_id,
-                    pip => ENERGENIE_DEFAULT_CRYPTPIP,
+                    pip => $msg->encrypt_pip,
                 );
                 
                 $outmsg->add_record(
                     id      => OPENTHINGS_PARAM_JOIN,
-                    wr      => 0,
+                    command => 0,
                     typeid  => OPENTHINGS_UINT,
                     value   => undef,
                 );
@@ -98,7 +102,7 @@ while (1) {
                 if ( $outmsg->ok ) {
                     print qq(\n\n\tMessage Sent Decoded OK\n);
                     for my $record ( @{ $outmsg->records } ) {
-                        printf(qq(\t%s = %s ( command bit %s)\n), $record->name, $record->value . $record->units, $record->wr || '0');
+                        printf(qq(\t%s = %s ( command bit %s)\n), $record->name, $record->value . $record->units, $record->command || '0');
                     }
                     $pending_reg->{$sensorkey} = 1;
                 } else {
@@ -109,9 +113,10 @@ while (1) {
                 }   
             }
         } else {
-            while ( my $error = $msg->shift_error ) {
-                print qq(\tERROR: $error\n);
-            }
+            # ignore bad fifo content
+            #while ( my $error = $msg->shift_error ) {
+            #    print qq(\tERROR: $error\n);
+            #}
         }
     }
     
@@ -135,19 +140,20 @@ while (1) {
             
             $switchmsg->add_record(
                 id      => OPENTHINGS_PARAM_SWITCH_STATE,
-                wr      => 1,
+                command => 1,
                 typeid  => OPENTHINGS_UINT,
                 value   => $newstate,
             );
             
-            $switchmsg->encode_buffer;
+            
             $handler->send_fsk_message( $switchmsg );
+            
             print qq(\nSent switch message to sensor $skey to set state $newstate\n);
             $switchmsg->decode_buffer;
                 
             if ( $switchmsg->ok ) {
                 for my $record ( @{ $switchmsg->records } ) {
-                    printf(qq(\t%s = %s ( command bit %s)\n), $record->name, $record->value . $record->units, $record->wr || '0');
+                    printf(qq(\t%s = %s ( command bit %s)\n), $record->name, $record->value . $record->units, $record->command || '0');
                 }
             }
         }
